'''OpenGL extension DFX.tbuffer

This module customises the behaviour of the 
OpenGL.raw.GL.DFX.tbuffer to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows a write mask to be defined for the fragment
	mask which is created during multisample rendering. This can be used
	to create effects such as motion blur and depth of field.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/DFX/tbuffer.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.DFX.tbuffer import *
from OpenGL.raw.GL.DFX.tbuffer import _EXTENSION_NAME

def glInitTbufferDFX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION