'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_texture_swizzle'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_texture_swizzle',error_checker=_errors._error_checker)
GL_TEXTURE_SWIZZLE_A_EXT=_C('GL_TEXTURE_SWIZZLE_A_EXT',0x8E45)
GL_TEXTURE_SWIZZLE_B_EXT=_C('GL_TEXTURE_SWIZZLE_B_EXT',0x8E44)
GL_TEXTURE_SWIZZLE_G_EXT=_C('GL_TEXTURE_SWIZZLE_G_EXT',0x8E43)
GL_TEXTURE_SWIZZLE_RGBA_EXT=_C('GL_TEXTURE_SWIZZLE_RGBA_EXT',0x8E46)
GL_TEXTURE_SWIZZLE_R_EXT=_C('GL_TEXTURE_SWIZZLE_R_EXT',0x8E42)

