'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_EXT_output_base'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_EXT_output_base',error_checker=_errors._error_checker)
EGL_BAD_OUTPUT_LAYER_EXT=_C('EGL_BAD_OUTPUT_LAYER_EXT',0x322D)
EGL_BAD_OUTPUT_PORT_EXT=_C('EGL_BAD_OUTPUT_PORT_EXT',0x322E)
# EGL_NO_OUTPUT_LAYER_EXT=_C('EGL_NO_OUTPUT_LAYER_EXT',((EGLOutputLayerEXT)0))
# EGL_NO_OUTPUT_PORT_EXT=_C('EGL_NO_OUTPUT_PORT_EXT',((EGLOutputPortEXT)0))
EGL_SWAP_INTERVAL_EXT=_C('EGL_SWAP_INTERVAL_EXT',0x322F)
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,arrays.EGLAttribArray,ctypes.POINTER(_cs.EGLOutputLayerEXT),_cs.EGLint,arrays.GLintArray)
def eglGetOutputLayersEXT(dpy,attrib_list,layers,max_layers,num_layers):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,arrays.EGLAttribArray,ctypes.POINTER(_cs.EGLOutputPortEXT),_cs.EGLint,arrays.GLintArray)
def eglGetOutputPortsEXT(dpy,attrib_list,ports,max_ports,num_ports):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLOutputLayerEXT,_cs.EGLint,_cs.EGLAttrib)
def eglOutputLayerAttribEXT(dpy,layer,attribute,value):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLOutputPortEXT,_cs.EGLint,_cs.EGLAttrib)
def eglOutputPortAttribEXT(dpy,port,attribute,value):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLOutputLayerEXT,_cs.EGLint,arrays.EGLAttribArray)
def eglQueryOutputLayerAttribEXT(dpy,layer,attribute,value):pass
@_f
@_p.types(ctypes.c_char_p,_cs.EGLDisplay,_cs.EGLOutputLayerEXT,_cs.EGLint)
def eglQueryOutputLayerStringEXT(dpy,layer,name):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLOutputPortEXT,_cs.EGLint,arrays.EGLAttribArray)
def eglQueryOutputPortAttribEXT(dpy,port,attribute,value):pass
@_f
@_p.types(ctypes.c_char_p,_cs.EGLDisplay,_cs.EGLOutputPortEXT,_cs.EGLint)
def eglQueryOutputPortStringEXT(dpy,port,name):pass
