'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_KHR_reusable_sync'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_KHR_reusable_sync',error_checker=_errors._error_checker)
EGL_CONDITION_SATISFIED_KHR=_C('EGL_CONDITION_SATISFIED_KHR',0x30F6)
EGL_FOREVER_KHR=_C('EGL_FOREVER_KHR',0xFFFFFFFFFFFFFFFF)
# EGL_NO_SYNC_KHR=_C('EGL_NO_SYNC_KHR',((EGLSyncKHR)0))
EGL_SIGNALED_KHR=_C('EGL_SIGNALED_KHR',0x30F2)
EGL_SYNC_FLUSH_COMMANDS_BIT_KHR=_C('EGL_SYNC_FLUSH_COMMANDS_BIT_KHR',0x0001)
EGL_SYNC_REUSABLE_KHR=_C('EGL_SYNC_REUSABLE_KHR',0x30FA)
EGL_SYNC_STATUS_KHR=_C('EGL_SYNC_STATUS_KHR',0x30F1)
EGL_SYNC_TYPE_KHR=_C('EGL_SYNC_TYPE_KHR',0x30F7)
EGL_TIMEOUT_EXPIRED_KHR=_C('EGL_TIMEOUT_EXPIRED_KHR',0x30F5)
EGL_UNSIGNALED_KHR=_C('EGL_UNSIGNALED_KHR',0x30F3)
@_f
@_p.types(_cs.EGLint,_cs.EGLDisplay,_cs.EGLSyncKHR,_cs.EGLint,_cs.EGLTimeKHR)
def eglClientWaitSyncKHR(dpy,sync,flags,timeout):pass
@_f
@_p.types(_cs.EGLSyncKHR,_cs.EGLDisplay,_cs.EGLenum,arrays.GLintArray)
def eglCreateSyncKHR(dpy,type,attrib_list):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSyncKHR)
def eglDestroySyncKHR(dpy,sync):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSyncKHR,_cs.EGLint,arrays.GLintArray)
def eglGetSyncAttribKHR(dpy,sync,attribute,value):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSyncKHR,_cs.EGLenum)
def eglSignalSyncKHR(dpy,sync,mode):pass
