'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_APPLE_object_purgeable'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_APPLE_object_purgeable',error_checker=_errors._error_checker)
GL_BUFFER_OBJECT_APPLE=_C('GL_BUFFER_OBJECT_APPLE',0x85B3)
GL_PURGEABLE_APPLE=_C('GL_PURGEABLE_APPLE',0x8A1D)
GL_RELEASED_APPLE=_C('GL_RELEASED_APPLE',0x8A19)
GL_RETAINED_APPLE=_C('GL_RETAINED_APPLE',0x8A1B)
GL_UNDEFINED_APPLE=_C('GL_UNDEFINED_APPLE',0x8A1C)
GL_VOLATILE_APPLE=_C('GL_VOLATILE_APPLE',0x8A1A)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetObjectParameterivAPPLE(objectType,name,pname,params):pass
@_f
@_p.types(_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLenum)
def glObjectPurgeableAPPLE(objectType,name,option):pass
@_f
@_p.types(_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLenum)
def glObjectUnpurgeableAPPLE(objectType,name,option):pass
