'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_OES_required_internalformat'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_OES_required_internalformat',error_checker=_errors._error_checker)
GL_ALPHA8_OES=_C('GL_ALPHA8_OES',0x803C)
GL_DEPTH24_STENCIL8_OES=_C('GL_DEPTH24_STENCIL8_OES',0x88F0)
GL_DEPTH_COMPONENT16_OES=_C('GL_DEPTH_COMPONENT16_OES',0x81A5)
GL_DEPTH_COMPONENT24_OES=_C('GL_DEPTH_COMPONENT24_OES',0x81A6)
GL_DEPTH_COMPONENT32_OES=_C('GL_DEPTH_COMPONENT32_OES',0x81A7)
GL_LUMINANCE4_ALPHA4_OES=_C('GL_LUMINANCE4_ALPHA4_OES',0x8043)
GL_LUMINANCE8_ALPHA8_OES=_C('GL_LUMINANCE8_ALPHA8_OES',0x8045)
GL_LUMINANCE8_OES=_C('GL_LUMINANCE8_OES',0x8040)
GL_RGB10_A2_EXT=_C('GL_RGB10_A2_EXT',0x8059)
GL_RGB10_EXT=_C('GL_RGB10_EXT',0x8052)
GL_RGB565_OES=_C('GL_RGB565_OES',0x8D62)
GL_RGB5_A1_OES=_C('GL_RGB5_A1_OES',0x8057)
GL_RGB8_OES=_C('GL_RGB8_OES',0x8051)
GL_RGBA4_OES=_C('GL_RGBA4_OES',0x8056)
GL_RGBA8_OES=_C('GL_RGBA8_OES',0x8058)

