'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_cl_event'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_cl_event',error_checker=_errors._error_checker)
GL_SYNC_CL_EVENT_ARB=_C('GL_SYNC_CL_EVENT_ARB',0x8240)
GL_SYNC_CL_EVENT_COMPLETE_ARB=_C('GL_SYNC_CL_EVENT_COMPLETE_ARB',0x8241)
@_f
@_p.types(_cs.GLsync,ctypes.POINTER(_cs._cl_context),ctypes.POINTER(_cs._cl_event),_cs.GLbitfield)
def glCreateSyncFromCLeventARB(context,event,flags):pass
