'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_VERSION_EGL_1_1'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_VERSION_EGL_1_1',error_checker=_errors._error_checker)
EGL_BACK_BUFFER=_C('EGL_BACK_BUFFER',0x3084)
EGL_BIND_TO_TEXTURE_RGB=_C('EGL_BIND_TO_TEXTURE_RGB',0x3039)
EGL_BIND_TO_TEXTURE_RGBA=_C('EGL_BIND_TO_TEXTURE_RGBA',0x303A)
EGL_CONTEXT_LOST=_C('EGL_CONTEXT_LOST',0x300E)
EGL_MAX_SWAP_INTERVAL=_C('EGL_MAX_SWAP_INTERVAL',0x303C)
EGL_MIN_SWAP_INTERVAL=_C('EGL_MIN_SWAP_INTERVAL',0x303B)
EGL_MIPMAP_LEVEL=_C('EGL_MIPMAP_LEVEL',0x3083)
EGL_MIPMAP_TEXTURE=_C('EGL_MIPMAP_TEXTURE',0x3082)
EGL_NO_TEXTURE=_C('EGL_NO_TEXTURE',0x305C)
EGL_TEXTURE_2D=_C('EGL_TEXTURE_2D',0x305F)
EGL_TEXTURE_FORMAT=_C('EGL_TEXTURE_FORMAT',0x3080)
EGL_TEXTURE_RGB=_C('EGL_TEXTURE_RGB',0x305D)
EGL_TEXTURE_RGBA=_C('EGL_TEXTURE_RGBA',0x305E)
EGL_TEXTURE_TARGET=_C('EGL_TEXTURE_TARGET',0x3081)
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSurface,_cs.EGLint)
def eglBindTexImage(dpy,surface,buffer):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSurface,_cs.EGLint)
def eglReleaseTexImage(dpy,surface,buffer):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSurface,_cs.EGLint,_cs.EGLint)
def eglSurfaceAttrib(dpy,surface,attribute,value):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLint)
def eglSwapInterval(dpy,interval):pass
