'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_multisample'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_multisample',error_checker=_errors._error_checker)
GL_MULTISAMPLE_ARB=_C('GL_MULTISAMPLE_ARB',0x809D)
GL_MULTISAMPLE_BIT_ARB=_C('GL_MULTISAMPLE_BIT_ARB',0x20000000)
GL_SAMPLES_ARB=_C('GL_SAMPLES_ARB',0x80A9)
GL_SAMPLE_ALPHA_TO_COVERAGE_ARB=_C('GL_SAMPLE_ALPHA_TO_COVERAGE_ARB',0x809E)
GL_SAMPLE_ALPHA_TO_ONE_ARB=_C('GL_SAMPLE_ALPHA_TO_ONE_ARB',0x809F)
GL_SAMPLE_BUFFERS_ARB=_C('GL_SAMPLE_BUFFERS_ARB',0x80A8)
GL_SAMPLE_COVERAGE_ARB=_C('GL_SAMPLE_COVERAGE_ARB',0x80A0)
GL_SAMPLE_COVERAGE_INVERT_ARB=_C('GL_SAMPLE_COVERAGE_INVERT_ARB',0x80AB)
GL_SAMPLE_COVERAGE_VALUE_ARB=_C('GL_SAMPLE_COVERAGE_VALUE_ARB',0x80AA)
@_f
@_p.types(None,_cs.GLfloat,_cs.GLboolean)
def glSampleCoverageARB(value,invert):pass
