'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_pipeline_statistics_query'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_pipeline_statistics_query',error_checker=_errors._error_checker)
GL_CLIPPING_INPUT_PRIMITIVES_ARB=_C('GL_CLIPPING_INPUT_PRIMITIVES_ARB',0x82F6)
GL_CLIPPING_OUTPUT_PRIMITIVES_ARB=_C('GL_CLIPPING_OUTPUT_PRIMITIVES_ARB',0x82F7)
GL_COMPUTE_SHADER_INVOCATIONS_ARB=_C('GL_COMPUTE_SHADER_INVOCATIONS_ARB',0x82F5)
GL_FRAGMENT_SHADER_INVOCATIONS_ARB=_C('GL_FRAGMENT_SHADER_INVOCATIONS_ARB',0x82F4)
GL_GEOMETRY_SHADER_INVOCATIONS=_C('GL_GEOMETRY_SHADER_INVOCATIONS',0x887F)
GL_GEOMETRY_SHADER_PRIMITIVES_EMITTED_ARB=_C('GL_GEOMETRY_SHADER_PRIMITIVES_EMITTED_ARB',0x82F3)
GL_PRIMITIVES_SUBMITTED_ARB=_C('GL_PRIMITIVES_SUBMITTED_ARB',0x82EF)
GL_TESS_CONTROL_SHADER_PATCHES_ARB=_C('GL_TESS_CONTROL_SHADER_PATCHES_ARB',0x82F1)
GL_TESS_EVALUATION_SHADER_INVOCATIONS_ARB=_C('GL_TESS_EVALUATION_SHADER_INVOCATIONS_ARB',0x82F2)
GL_VERTEX_SHADER_INVOCATIONS_ARB=_C('GL_VERTEX_SHADER_INVOCATIONS_ARB',0x82F0)
GL_VERTICES_SUBMITTED_ARB=_C('GL_VERTICES_SUBMITTED_ARB',0x82EE)

