"""Constants for OpenGL.GLUT

Automatically generated by the generateraw script, do not edit!
"""

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL.raw.GL import _types as GL_types
GLvoid = GL_types.GLvoid



GLUT_ACCUM = Constant( 'GLUT_ACCUM', 4)
GLUT_ACTIVE_ALT = Constant( 'GLUT_ACTIVE_ALT', 4)
GLUT_ACTIVE_CTRL = Constant( 'GLUT_ACTIVE_CTRL', 2)
GLUT_ACTIVE_SHIFT = Constant( 'GLUT_ACTIVE_SHIFT', 1)
GLUT_ALPHA = Constant( 'GLUT_ALPHA', 8)
GLUT_API_VERSION = Constant( 'GLUT_API_VERSION', 4)
GLUT_BLUE = Constant( 'GLUT_BLUE', 2)
GLUT_CURSOR_BOTTOM_LEFT_CORNER = Constant( 'GLUT_CURSOR_BOTTOM_LEFT_CORNER', 19)
GLUT_CURSOR_BOTTOM_RIGHT_CORNER = Constant( 'GLUT_CURSOR_BOTTOM_RIGHT_CORNER', 18)
GLUT_CURSOR_BOTTOM_SIDE = Constant( 'GLUT_CURSOR_BOTTOM_SIDE', 13)
GLUT_CURSOR_CROSSHAIR = Constant( 'GLUT_CURSOR_CROSSHAIR', 9)
GLUT_CURSOR_CYCLE = Constant( 'GLUT_CURSOR_CYCLE', 5)
GLUT_CURSOR_DESTROY = Constant( 'GLUT_CURSOR_DESTROY', 3)
GLUT_CURSOR_FULL_CROSSHAIR = Constant( 'GLUT_CURSOR_FULL_CROSSHAIR', 102)
GLUT_CURSOR_HELP = Constant( 'GLUT_CURSOR_HELP', 4)
GLUT_CURSOR_INFO = Constant( 'GLUT_CURSOR_INFO', 2)
GLUT_CURSOR_INHERIT = Constant( 'GLUT_CURSOR_INHERIT', 100)
GLUT_CURSOR_LEFT_ARROW = Constant( 'GLUT_CURSOR_LEFT_ARROW', 1)
GLUT_CURSOR_LEFT_RIGHT = Constant( 'GLUT_CURSOR_LEFT_RIGHT', 11)
GLUT_CURSOR_LEFT_SIDE = Constant( 'GLUT_CURSOR_LEFT_SIDE', 14)
GLUT_CURSOR_NONE = Constant( 'GLUT_CURSOR_NONE', 101)
GLUT_CURSOR_RIGHT_ARROW = Constant( 'GLUT_CURSOR_RIGHT_ARROW', 0)
GLUT_CURSOR_RIGHT_SIDE = Constant( 'GLUT_CURSOR_RIGHT_SIDE', 15)
GLUT_CURSOR_SPRAY = Constant( 'GLUT_CURSOR_SPRAY', 6)
GLUT_CURSOR_TEXT = Constant( 'GLUT_CURSOR_TEXT', 8)
GLUT_CURSOR_TOP_LEFT_CORNER = Constant( 'GLUT_CURSOR_TOP_LEFT_CORNER', 16)
GLUT_CURSOR_TOP_RIGHT_CORNER = Constant( 'GLUT_CURSOR_TOP_RIGHT_CORNER', 17)
GLUT_CURSOR_TOP_SIDE = Constant( 'GLUT_CURSOR_TOP_SIDE', 12)
GLUT_CURSOR_UP_DOWN = Constant( 'GLUT_CURSOR_UP_DOWN', 10)
GLUT_CURSOR_WAIT = Constant( 'GLUT_CURSOR_WAIT', 7)
GLUT_DEPTH = Constant( 'GLUT_DEPTH', 16)
GLUT_DEVICE_IGNORE_KEY_REPEAT = Constant( 'GLUT_DEVICE_IGNORE_KEY_REPEAT', 610)
GLUT_DEVICE_KEY_REPEAT = Constant( 'GLUT_DEVICE_KEY_REPEAT', 611)
GLUT_DISPLAY_MODE_POSSIBLE = Constant( 'GLUT_DISPLAY_MODE_POSSIBLE', 400)
GLUT_DOUBLE = Constant( 'GLUT_DOUBLE', 2)
GLUT_DOWN = Constant( 'GLUT_DOWN', 0)
GLUT_ELAPSED_TIME = Constant( 'GLUT_ELAPSED_TIME', 700)
GLUT_ENTERED = Constant( 'GLUT_ENTERED', 1)
GLUT_FULLY_COVERED = Constant( 'GLUT_FULLY_COVERED', 3)
GLUT_FULLY_RETAINED = Constant( 'GLUT_FULLY_RETAINED', 1)
GLUT_GAME_MODE_ACTIVE = Constant( 'GLUT_GAME_MODE_ACTIVE', 0)
GLUT_GAME_MODE_DISPLAY_CHANGED = Constant( 'GLUT_GAME_MODE_DISPLAY_CHANGED', 6)
GLUT_GAME_MODE_HEIGHT = Constant( 'GLUT_GAME_MODE_HEIGHT', 3)
GLUT_GAME_MODE_PIXEL_DEPTH = Constant( 'GLUT_GAME_MODE_PIXEL_DEPTH', 4)
GLUT_GAME_MODE_POSSIBLE = Constant( 'GLUT_GAME_MODE_POSSIBLE', 1)
GLUT_GAME_MODE_REFRESH_RATE = Constant( 'GLUT_GAME_MODE_REFRESH_RATE', 5)
GLUT_GAME_MODE_WIDTH = Constant( 'GLUT_GAME_MODE_WIDTH', 2)
GLUT_GREEN = Constant( 'GLUT_GREEN', 1)
GLUT_HAS_DIAL_AND_BUTTON_BOX = Constant( 'GLUT_HAS_DIAL_AND_BUTTON_BOX', 603)
GLUT_HAS_JOYSTICK = Constant( 'GLUT_HAS_JOYSTICK', 612)
GLUT_HAS_KEYBOARD = Constant( 'GLUT_HAS_KEYBOARD', 600)
GLUT_HAS_MOUSE = Constant( 'GLUT_HAS_MOUSE', 601)
GLUT_HAS_OVERLAY = Constant( 'GLUT_HAS_OVERLAY', 802)
GLUT_HAS_SPACEBALL = Constant( 'GLUT_HAS_SPACEBALL', 602)
GLUT_HAS_TABLET = Constant( 'GLUT_HAS_TABLET', 604)
GLUT_HIDDEN = Constant( 'GLUT_HIDDEN', 0)
GLUT_INDEX = Constant( 'GLUT_INDEX', 1)
GLUT_INIT_DISPLAY_MODE = Constant( 'GLUT_INIT_DISPLAY_MODE', 504)
GLUT_INIT_STATE = Constant( 'GLUT_INIT_STATE', 124)
GLUT_INIT_WINDOW_HEIGHT = Constant( 'GLUT_INIT_WINDOW_HEIGHT', 503)
GLUT_INIT_WINDOW_WIDTH = Constant( 'GLUT_INIT_WINDOW_WIDTH', 502)
GLUT_INIT_WINDOW_X = Constant( 'GLUT_INIT_WINDOW_X', 500)
GLUT_INIT_WINDOW_Y = Constant( 'GLUT_INIT_WINDOW_Y', 501)
GLUT_JOYSTICK_AXES = Constant( 'GLUT_JOYSTICK_AXES', 615)
GLUT_JOYSTICK_BUTTONS = Constant( 'GLUT_JOYSTICK_BUTTONS', 614)
GLUT_JOYSTICK_BUTTON_A = Constant( 'GLUT_JOYSTICK_BUTTON_A', 1)
GLUT_JOYSTICK_BUTTON_B = Constant( 'GLUT_JOYSTICK_BUTTON_B', 2)
GLUT_JOYSTICK_BUTTON_C = Constant( 'GLUT_JOYSTICK_BUTTON_C', 4)
GLUT_JOYSTICK_BUTTON_D = Constant( 'GLUT_JOYSTICK_BUTTON_D', 8)
GLUT_JOYSTICK_POLL_RATE = Constant( 'GLUT_JOYSTICK_POLL_RATE', 616)
GLUT_KEY_DOWN = Constant( 'GLUT_KEY_DOWN', 103)
GLUT_KEY_END = Constant( 'GLUT_KEY_END', 107)
GLUT_KEY_F1 = Constant( 'GLUT_KEY_F1', 1)
GLUT_KEY_F10 = Constant( 'GLUT_KEY_F10', 10)
GLUT_KEY_F11 = Constant( 'GLUT_KEY_F11', 11)
GLUT_KEY_F12 = Constant( 'GLUT_KEY_F12', 12)
GLUT_KEY_F2 = Constant( 'GLUT_KEY_F2', 2)
GLUT_KEY_F3 = Constant( 'GLUT_KEY_F3', 3)
GLUT_KEY_F4 = Constant( 'GLUT_KEY_F4', 4)
GLUT_KEY_F5 = Constant( 'GLUT_KEY_F5', 5)
GLUT_KEY_F6 = Constant( 'GLUT_KEY_F6', 6)
GLUT_KEY_F7 = Constant( 'GLUT_KEY_F7', 7)
GLUT_KEY_F8 = Constant( 'GLUT_KEY_F8', 8)
GLUT_KEY_F9 = Constant( 'GLUT_KEY_F9', 9)
GLUT_KEY_HOME = Constant( 'GLUT_KEY_HOME', 106)
GLUT_KEY_INSERT = Constant( 'GLUT_KEY_INSERT', 108)
GLUT_KEY_LEFT = Constant( 'GLUT_KEY_LEFT', 100)
GLUT_KEY_PAGE_DOWN = Constant( 'GLUT_KEY_PAGE_DOWN', 105)
GLUT_KEY_PAGE_UP = Constant( 'GLUT_KEY_PAGE_UP', 104)
GLUT_KEY_REPEAT_DEFAULT = Constant( 'GLUT_KEY_REPEAT_DEFAULT', 2)
GLUT_KEY_REPEAT_OFF = Constant( 'GLUT_KEY_REPEAT_OFF', 0)
GLUT_KEY_REPEAT_ON = Constant( 'GLUT_KEY_REPEAT_ON', 1)
GLUT_KEY_RIGHT = Constant( 'GLUT_KEY_RIGHT', 102)
GLUT_KEY_UP = Constant( 'GLUT_KEY_UP', 101)
GLUT_LAYER_IN_USE = Constant( 'GLUT_LAYER_IN_USE', 801)
GLUT_LEFT = Constant( 'GLUT_LEFT', 0)
GLUT_LEFT_BUTTON = Constant( 'GLUT_LEFT_BUTTON', 0)
GLUT_LUMINANCE = Constant( 'GLUT_LUMINANCE', 512)
GLUT_MENU_IN_USE = Constant( 'GLUT_MENU_IN_USE', 1)
GLUT_MENU_NOT_IN_USE = Constant( 'GLUT_MENU_NOT_IN_USE', 0)
GLUT_MENU_NUM_ITEMS = Constant( 'GLUT_MENU_NUM_ITEMS', 300)
GLUT_MIDDLE_BUTTON = Constant( 'GLUT_MIDDLE_BUTTON', 1)
GLUT_MULTISAMPLE = Constant( 'GLUT_MULTISAMPLE', 128)
GLUT_NORMAL = Constant( 'GLUT_NORMAL', 0)
GLUT_NORMAL_DAMAGED = Constant( 'GLUT_NORMAL_DAMAGED', 804)
GLUT_NOT_VISIBLE = Constant( 'GLUT_NOT_VISIBLE', 0)
GLUT_NUM_BUTTON_BOX_BUTTONS = Constant( 'GLUT_NUM_BUTTON_BOX_BUTTONS', 607)
GLUT_NUM_DIALS = Constant( 'GLUT_NUM_DIALS', 608)
GLUT_NUM_MOUSE_BUTTONS = Constant( 'GLUT_NUM_MOUSE_BUTTONS', 605)
GLUT_NUM_SPACEBALL_BUTTONS = Constant( 'GLUT_NUM_SPACEBALL_BUTTONS', 606)
GLUT_NUM_TABLET_BUTTONS = Constant( 'GLUT_NUM_TABLET_BUTTONS', 609)
GLUT_OVERLAY = Constant( 'GLUT_OVERLAY', 1)
GLUT_OVERLAY_DAMAGED = Constant( 'GLUT_OVERLAY_DAMAGED', 805)
GLUT_OVERLAY_POSSIBLE = Constant( 'GLUT_OVERLAY_POSSIBLE', 800)
GLUT_OWNS_JOYSTICK = Constant( 'GLUT_OWNS_JOYSTICK', 613)
GLUT_PARTIALLY_RETAINED = Constant( 'GLUT_PARTIALLY_RETAINED', 2)
GLUT_RED = Constant( 'GLUT_RED', 0)
GLUT_RGB = Constant( 'GLUT_RGB', 0)
GLUT_RGBA = Constant( 'GLUT_RGBA', 0)
GLUT_RIGHT_BUTTON = Constant( 'GLUT_RIGHT_BUTTON', 2)
GLUT_SCREEN_HEIGHT = Constant( 'GLUT_SCREEN_HEIGHT', 201)
GLUT_SCREEN_HEIGHT_MM = Constant( 'GLUT_SCREEN_HEIGHT_MM', 203)
GLUT_SCREEN_WIDTH = Constant( 'GLUT_SCREEN_WIDTH', 200)
GLUT_SCREEN_WIDTH_MM = Constant( 'GLUT_SCREEN_WIDTH_MM', 202)
GLUT_SINGLE = Constant( 'GLUT_SINGLE', 0)
GLUT_STENCIL = Constant( 'GLUT_STENCIL', 32)
GLUT_STEREO = Constant( 'GLUT_STEREO', 256)
GLUT_TRANSPARENT_INDEX = Constant( 'GLUT_TRANSPARENT_INDEX', 803)
GLUT_UP = Constant( 'GLUT_UP', 1)
GLUT_VIDEO_RESIZE_HEIGHT = Constant( 'GLUT_VIDEO_RESIZE_HEIGHT', 909)
GLUT_VIDEO_RESIZE_HEIGHT_DELTA = Constant( 'GLUT_VIDEO_RESIZE_HEIGHT_DELTA', 905)
GLUT_VIDEO_RESIZE_IN_USE = Constant( 'GLUT_VIDEO_RESIZE_IN_USE', 901)
GLUT_VIDEO_RESIZE_POSSIBLE = Constant( 'GLUT_VIDEO_RESIZE_POSSIBLE', 900)
GLUT_VIDEO_RESIZE_WIDTH = Constant( 'GLUT_VIDEO_RESIZE_WIDTH', 908)
GLUT_VIDEO_RESIZE_WIDTH_DELTA = Constant( 'GLUT_VIDEO_RESIZE_WIDTH_DELTA', 904)
GLUT_VIDEO_RESIZE_X = Constant( 'GLUT_VIDEO_RESIZE_X', 906)
GLUT_VIDEO_RESIZE_X_DELTA = Constant( 'GLUT_VIDEO_RESIZE_X_DELTA', 902)
GLUT_VIDEO_RESIZE_Y = Constant( 'GLUT_VIDEO_RESIZE_Y', 907)
GLUT_VIDEO_RESIZE_Y_DELTA = Constant( 'GLUT_VIDEO_RESIZE_Y_DELTA', 903)
GLUT_VISIBLE = Constant( 'GLUT_VISIBLE', 1)
GLUT_WINDOW_ACCUM_ALPHA_SIZE = Constant( 'GLUT_WINDOW_ACCUM_ALPHA_SIZE', 114)
GLUT_WINDOW_ACCUM_BLUE_SIZE = Constant( 'GLUT_WINDOW_ACCUM_BLUE_SIZE', 113)
GLUT_WINDOW_ACCUM_GREEN_SIZE = Constant( 'GLUT_WINDOW_ACCUM_GREEN_SIZE', 112)
GLUT_WINDOW_ACCUM_RED_SIZE = Constant( 'GLUT_WINDOW_ACCUM_RED_SIZE', 111)
GLUT_WINDOW_ALPHA_SIZE = Constant( 'GLUT_WINDOW_ALPHA_SIZE', 110)
GLUT_WINDOW_BLUE_SIZE = Constant( 'GLUT_WINDOW_BLUE_SIZE', 109)
GLUT_WINDOW_BUFFER_SIZE = Constant( 'GLUT_WINDOW_BUFFER_SIZE', 104)
GLUT_WINDOW_COLORMAP_SIZE = Constant( 'GLUT_WINDOW_COLORMAP_SIZE', 119)
GLUT_WINDOW_CURSOR = Constant( 'GLUT_WINDOW_CURSOR', 122)
GLUT_WINDOW_DEPTH_SIZE = Constant( 'GLUT_WINDOW_DEPTH_SIZE', 106)
GLUT_WINDOW_DOUBLEBUFFER = Constant( 'GLUT_WINDOW_DOUBLEBUFFER', 115)
GLUT_WINDOW_FORMAT_ID = Constant( 'GLUT_WINDOW_FORMAT_ID', 123)
GLUT_WINDOW_GREEN_SIZE = Constant( 'GLUT_WINDOW_GREEN_SIZE', 108)
GLUT_WINDOW_HEIGHT = Constant( 'GLUT_WINDOW_HEIGHT', 103)
GLUT_WINDOW_NUM_CHILDREN = Constant( 'GLUT_WINDOW_NUM_CHILDREN', 118)
GLUT_WINDOW_NUM_SAMPLES = Constant( 'GLUT_WINDOW_NUM_SAMPLES', 120)
GLUT_WINDOW_PARENT = Constant( 'GLUT_WINDOW_PARENT', 117)
GLUT_WINDOW_RED_SIZE = Constant( 'GLUT_WINDOW_RED_SIZE', 107)
GLUT_WINDOW_RGBA = Constant( 'GLUT_WINDOW_RGBA', 116)
GLUT_WINDOW_STENCIL_SIZE = Constant( 'GLUT_WINDOW_STENCIL_SIZE', 105)
GLUT_WINDOW_STEREO = Constant( 'GLUT_WINDOW_STEREO', 121)
GLUT_WINDOW_WIDTH = Constant( 'GLUT_WINDOW_WIDTH', 102)
GLUT_WINDOW_X = Constant( 'GLUT_WINDOW_X', 100)
GLUT_WINDOW_Y = Constant( 'GLUT_WINDOW_Y', 101)
GLUT_XLIB_IMPLEMENTATION = Constant( 'GLUT_XLIB_IMPLEMENTATION', 13)
__all__ = [
    'GLUT_ACCUM',
    'GLUT_ACTIVE_ALT',
    'GLUT_ACTIVE_CTRL',
    'GLUT_ACTIVE_SHIFT',
    'GLUT_ALPHA',
    'GLUT_API_VERSION',
    'GLUT_BLUE',
    'GLUT_CURSOR_BOTTOM_LEFT_CORNER',
    'GLUT_CURSOR_BOTTOM_RIGHT_CORNER',
    'GLUT_CURSOR_BOTTOM_SIDE',
    'GLUT_CURSOR_CROSSHAIR',
    'GLUT_CURSOR_CYCLE',
    'GLUT_CURSOR_DESTROY',
    'GLUT_CURSOR_FULL_CROSSHAIR',
    'GLUT_CURSOR_HELP',
    'GLUT_CURSOR_INFO',
    'GLUT_CURSOR_INHERIT',
    'GLUT_CURSOR_LEFT_ARROW',
    'GLUT_CURSOR_LEFT_RIGHT',
    'GLUT_CURSOR_LEFT_SIDE',
    'GLUT_CURSOR_NONE',
    'GLUT_CURSOR_RIGHT_ARROW',
    'GLUT_CURSOR_RIGHT_SIDE',
    'GLUT_CURSOR_SPRAY',
    'GLUT_CURSOR_TEXT',
    'GLUT_CURSOR_TOP_LEFT_CORNER',
    'GLUT_CURSOR_TOP_RIGHT_CORNER',
    'GLUT_CURSOR_TOP_SIDE',
    'GLUT_CURSOR_UP_DOWN',
    'GLUT_CURSOR_WAIT',
    'GLUT_DEPTH',
    'GLUT_DEVICE_IGNORE_KEY_REPEAT',
    'GLUT_DEVICE_KEY_REPEAT',
    'GLUT_DISPLAY_MODE_POSSIBLE',
    'GLUT_DOUBLE',
    'GLUT_DOWN',
    'GLUT_ELAPSED_TIME',
    'GLUT_ENTERED',
    'GLUT_FULLY_COVERED',
    'GLUT_FULLY_RETAINED',
    'GLUT_GAME_MODE_ACTIVE',
    'GLUT_GAME_MODE_DISPLAY_CHANGED',
    'GLUT_GAME_MODE_HEIGHT',
    'GLUT_GAME_MODE_PIXEL_DEPTH',
    'GLUT_GAME_MODE_POSSIBLE',
    'GLUT_GAME_MODE_REFRESH_RATE',
    'GLUT_GAME_MODE_WIDTH',
    'GLUT_GREEN',
    'GLUT_HAS_DIAL_AND_BUTTON_BOX',
    'GLUT_HAS_JOYSTICK',
    'GLUT_HAS_KEYBOARD',
    'GLUT_HAS_MOUSE',
    'GLUT_HAS_OVERLAY',
    'GLUT_HAS_SPACEBALL',
    'GLUT_HAS_TABLET',
    'GLUT_HIDDEN',
    'GLUT_INDEX',
    'GLUT_INIT_DISPLAY_MODE',
    'GLUT_INIT_STATE',
    'GLUT_INIT_WINDOW_HEIGHT',
    'GLUT_INIT_WINDOW_WIDTH',
    'GLUT_INIT_WINDOW_X',
    'GLUT_INIT_WINDOW_Y',
    'GLUT_JOYSTICK_AXES',
    'GLUT_JOYSTICK_BUTTONS',
    'GLUT_JOYSTICK_BUTTON_A',
    'GLUT_JOYSTICK_BUTTON_B',
    'GLUT_JOYSTICK_BUTTON_C',
    'GLUT_JOYSTICK_BUTTON_D',
    'GLUT_JOYSTICK_POLL_RATE',
    'GLUT_KEY_DOWN',
    'GLUT_KEY_END',
    'GLUT_KEY_F1',
    'GLUT_KEY_F10',
    'GLUT_KEY_F11',
    'GLUT_KEY_F12',
    'GLUT_KEY_F2',
    'GLUT_KEY_F3',
    'GLUT_KEY_F4',
    'GLUT_KEY_F5',
    'GLUT_KEY_F6',
    'GLUT_KEY_F7',
    'GLUT_KEY_F8',
    'GLUT_KEY_F9',
    'GLUT_KEY_HOME',
    'GLUT_KEY_INSERT',
    'GLUT_KEY_LEFT',
    'GLUT_KEY_PAGE_DOWN',
    'GLUT_KEY_PAGE_UP',
    'GLUT_KEY_REPEAT_DEFAULT',
    'GLUT_KEY_REPEAT_OFF',
    'GLUT_KEY_REPEAT_ON',
    'GLUT_KEY_RIGHT',
    'GLUT_KEY_UP',
    'GLUT_LAYER_IN_USE',
    'GLUT_LEFT',
    'GLUT_LEFT_BUTTON',
    'GLUT_LUMINANCE',
    'GLUT_MENU_IN_USE',
    'GLUT_MENU_NOT_IN_USE',
    'GLUT_MENU_NUM_ITEMS',
    'GLUT_MIDDLE_BUTTON',
    'GLUT_MULTISAMPLE',
    'GLUT_NORMAL',
    'GLUT_NORMAL_DAMAGED',
    'GLUT_NOT_VISIBLE',
    'GLUT_NUM_BUTTON_BOX_BUTTONS',
    'GLUT_NUM_DIALS',
    'GLUT_NUM_MOUSE_BUTTONS',
    'GLUT_NUM_SPACEBALL_BUTTONS',
    'GLUT_NUM_TABLET_BUTTONS',
    'GLUT_OVERLAY',
    'GLUT_OVERLAY_DAMAGED',
    'GLUT_OVERLAY_POSSIBLE',
    'GLUT_OWNS_JOYSTICK',
    'GLUT_PARTIALLY_RETAINED',
    'GLUT_RED',
    'GLUT_RGB',
    'GLUT_RGBA',
    'GLUT_RIGHT_BUTTON',
    'GLUT_SCREEN_HEIGHT',
    'GLUT_SCREEN_HEIGHT_MM',
    'GLUT_SCREEN_WIDTH',
    'GLUT_SCREEN_WIDTH_MM',
    'GLUT_SINGLE',
    'GLUT_STENCIL',
    'GLUT_STEREO',
    'GLUT_TRANSPARENT_INDEX',
    'GLUT_UP',
    'GLUT_VIDEO_RESIZE_HEIGHT',
    'GLUT_VIDEO_RESIZE_HEIGHT_DELTA',
    'GLUT_VIDEO_RESIZE_IN_USE',
    'GLUT_VIDEO_RESIZE_POSSIBLE',
    'GLUT_VIDEO_RESIZE_WIDTH',
    'GLUT_VIDEO_RESIZE_WIDTH_DELTA',
    'GLUT_VIDEO_RESIZE_X',
    'GLUT_VIDEO_RESIZE_X_DELTA',
    'GLUT_VIDEO_RESIZE_Y',
    'GLUT_VIDEO_RESIZE_Y_DELTA',
    'GLUT_VISIBLE',
    'GLUT_WINDOW_ACCUM_ALPHA_SIZE',
    'GLUT_WINDOW_ACCUM_BLUE_SIZE',
    'GLUT_WINDOW_ACCUM_GREEN_SIZE',
    'GLUT_WINDOW_ACCUM_RED_SIZE',
    'GLUT_WINDOW_ALPHA_SIZE',
    'GLUT_WINDOW_BLUE_SIZE',
    'GLUT_WINDOW_BUFFER_SIZE',
    'GLUT_WINDOW_COLORMAP_SIZE',
    'GLUT_WINDOW_CURSOR',
    'GLUT_WINDOW_DEPTH_SIZE',
    'GLUT_WINDOW_DOUBLEBUFFER',
    'GLUT_WINDOW_FORMAT_ID',
    'GLUT_WINDOW_GREEN_SIZE',
    'GLUT_WINDOW_HEIGHT',
    'GLUT_WINDOW_NUM_CHILDREN',
    'GLUT_WINDOW_NUM_SAMPLES',
    'GLUT_WINDOW_PARENT',
    'GLUT_WINDOW_RED_SIZE',
    'GLUT_WINDOW_RGBA',
    'GLUT_WINDOW_STENCIL_SIZE',
    'GLUT_WINDOW_STEREO',
    'GLUT_WINDOW_WIDTH',
    'GLUT_WINDOW_X',
    'GLUT_WINDOW_Y',
    'GLUT_XLIB_IMPLEMENTATION'
]
